@@ -4,9 +4,8 @@
 #
 # ------------------------------------------------------------------------------
 
-import importlib
 import os
-from importlib.metadata import version
+from importlib.metadata import PackageNotFoundError, version
 from os.path import *
 from typing import *
 
@@ -48,7 +47,11 @@ def GetRequirements(path: str, *, seperator: str = '>=') -> List[str]:
     install_requires: List[str] = []
     for line in ReadLinesFromFile(path):
         line = line.strip()
-        install_requires.append(f'{line}{seperator}{version(line)}')
+        if not line: continue
+        try:
+            install_requires.append(f'{line}{seperator}{version(line)}')
+        except PackageNotFoundError as e:
+            raise PackageNotFoundError(f'package "{line}" not found') from e
 
     return install_requires
 
